Observable<T> class

A data wrapper class that helps with keep track of any actions applied to any data/state, it can also store a history of all actions applied to this data.

Constructors

Observable([String? alias])
Observable.initialized(T value, [String? alias])

Properties

alias → String?
final
hashCode → int
The hash code for this object.
no setterinherited
hasValue → bool
no setter
history → List<ObservableAction<T>>
no setter
prevValue → T?
getters
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stream → Stream<T>
no setter
value → T
no setter
valueOrNull → T?
no setter

Methods

clearHistory() → void
log(ValueChangedCallback<T> callback) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetLogCallback() → void
setValue(T value, {required String action}) → void
toString() → String
A string representation of this object.
inherited
valueOrDefault(T defaultValue) → T?
methods

Operators

operator ==(Object other) → bool
The equality operator.
inherited