MVVMBaseProps<T extends ViewModel> class

Implementers

Constructors

MVVMBaseProps({required T viewModel, required bool disposeVM})

Properties

disposeVM → bool
To dispose the viewModel when the provider is removed from the widget tree.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
viewModel → T
The view model of the view.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited